unit Unit1;

{$mode objfpc}{$H+}

interface

uses
  Classes, SysUtils, Forms, Controls, Graphics, Dialogs, StdCtrls, LR_Class,
  LR_CodeReport, fpjsonrtti,printers
  //, fpjson
  ;
type
  TGenType = (gtPreview, gtPDF, gtPrint);
  { TForm1 }

  TForm1 = class(TForm)
    bttn_ObjToJson: TButton;
    bttn_JsonToObj: TButton;
    bttn_OpenFontDialog: TButton;
    Button1: TButton;
    frReport1: TfrReport;
    Label1: TLabel;
    lrcr: TlrCodeReport;
    Memo1: TMemo;
    procedure bttn_ObjToJsonClick(Sender: TObject);
    procedure bttn_JsonToObjClick(Sender: TObject);
    procedure bttn_OpenFontDialogClick(Sender: TObject);
    procedure Button1Click(Sender: TObject);
  private

  public
    procedure GenerateReport;
    procedure TemplateLabels(Sender: TObject);
    procedure DrawPageMargins(Sender: TObject);
  end;

var
  Form1: TForm1;

implementation

{$R *.lfm}

{ TForm1 }

{
https://wiki.freepascal.org/Streaming_JSON
}

procedure TForm1.bttn_ObjToJsonClick(Sender: TObject);
var
  Streamer: TJSONStreamer;
begin
  Streamer := TJSONStreamer.Create(nil);
  try
    Streamer.Options := Streamer.Options + [jsoTStringsAsArray]; // Save strings as JSON array
    Memo1.Lines.Text := Streamer.ObjectToJSONString(Label1.Font);
  finally
    Streamer.Destroy;
  end;
end;

procedure TForm1.bttn_JsonToObjClick(Sender: TObject);
var
  DeStreamer: TJSONDeStreamer;
begin
  DeStreamer := TJSONDeStreamer.Create(nil);
  try
    DeStreamer.JSONToObject(Memo1.Lines.Text, Label1.Font);
   // Label2.Caption:= 'Size '+ inttostr(Label1.Font.Size);
  finally
    DEStreamer.Destroy;
  end;
end;

procedure TForm1.bttn_OpenFontDialogClick(Sender: TObject);
var
  FD:TFontDialog;
begin
  FD:=TFontDialog.Create(self);
  try
    FD.Font:=Label1.Font;
    if FD.Execute then Label1.Font:=FD.Font;
  finally
    FD.Free;
  end;

end;

procedure TForm1.Button1Click(Sender: TObject);
begin
  GenerateReport;
end;

procedure TForm1.GenerateReport;
begin
  lrcr.Report.Clear;
  lrcr.OnBeginReport := @TemplateLabels;

  lrcr.RunReport;

end;

procedure TForm1.TemplateLabels(Sender: TObject);
begin
  with Sender as TlrCodeReport do
  begin
    SetRatio(trunc(91 / 25.4), trunc(91 / 25.4)); //set dimensions in mm
    NewPage;                                      //add page
    SetPaper(9 {A4}, poPortrait);                 //set page format
    DrawPageMargins(Sender);                      //draw Page Margins
  end;
end;

procedure TForm1.DrawPageMargins(Sender: TObject);
var
  dH,dW:double;       //height/width
  TextStyle: TlrTextRectStyle;
begin
  with Sender as TlrCodeReport do
  begin
    TextStyle := GetDefaultTextRectStyle;
    TextStyle.FontName := 'Arial';
    TextStyle.FontSize := 12;
    TextStyle.WordWrap := True;
    TextStyle.WordBreak := True;
    TextStyle.FontColor := clBlack;

    //line style
    TextStyle.Line.LWidth := 0.1;
    TextStyle.BorderLines:=[frbLeft, frbTop, frbRight, frbBottom];
    TextStyle.Line.LColor := clRed;
    TextStyle.FillColor:=$00C6FABC;
    TextStyle.Alignment:=taRightJustify;


    //*********
    //*********
    //**** How to transfer Font Object Info from string (Memo1.Text) to Textstyle ?
    //*********
    //*********




    dh:= GetPageHeight - 8 - 8;
    dW:= GetPageWidth - 8 - 8 ;

    //alternatively you can use a text frame
    DrawText( 8, 8, dW, dH, 'Page Margins', TextStyle);

    //DrawFrame( rl.PageFrameLeft, rl.PageFrameTop, dW, dH, TextStyle);
  end;

end;

end.

